@@ -10,7 +10,7 @@ use Data::Section { installer => method_installer }, -setup;
 use Dist::Zilla::MintingProfile::Author::Plicease;
 
 # ABSTRACT: add author only release tests to xt/release
-our $VERSION = '2.07'; # VERSION
+our $VERSION = '2.09'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileGatherer';
@@ -70,7 +70,7 @@ sub before_build
 
   my $source = defined $self->source
   ? dir($self->zilla->root)->subdir($self->source)
-  : Dist::Zilla::MintingProfile::Author::Plicease->profile_dir->subdir(qw( default skel xt release ));
+  : dir(Dist::Zilla::MintingProfile::Author::Plicease->profile_dir)->subdir(qw( default skel xt release ));
 
   my $diag = dir($self->zilla->root)->file(qw( t 00_diag.t ));
   my $content = $source->parent->parent->file('t', '00_diag.t')->absolute->slurp;
@@ -177,7 +177,7 @@ Dist::Zilla::Plugin::Author::Plicease::Tests - add author only release tests to
 
 =head1 VERSION
 
-version 2.07
+version 2.09
 
 =head1 SYNOPSIS
 
